@@ -75,6 +75,7 @@ pub mod scala;
 pub mod shell;
 pub mod shlvl;
 pub mod singularity;
+pub mod solidity;
 pub mod spack;
 mod starship_root;
 pub mod status;
@@ -251,6 +252,8 @@ pub struct FullConfig<'a> {
     #[serde(borrow)]
     singularity: singularity::SingularityConfig<'a>,
     #[serde(borrow)]
+    solidity: solidity::SolidityConfig<'a>,
+    #[serde(borrow)]
     spack: spack::SpackConfig<'a>,
     #[serde(borrow)]
     status: status::StatusConfig<'a>,
