@@ -413,6 +413,14 @@ Built on MoarVM version 2021.12.\n",
             stdout: String::from("ruby 2.5.1p57 (2018-03-29 revision 63029) [x86_64-linux-gnu]\n"),
             stderr: String::default(),
         }),
+        "solc --version" => Some(CommandOutput {
+            stdout: String::from("solc, the solidity compiler commandline interface
+Version: 0.8.16+commit.07a7930e.Linux.g++"),
+            stderr: String::default(),
+        }),
+        "solcjs --version" => Some(CommandOutput {
+            stdout: String::from("0.8.15+commit.e14f2714.Emscripten.clang"),
+            stderr: String::default() }),
         "swift --version" => Some(CommandOutput {
             stdout: String::from(
                 "\
